==> redux-subspace-observable-4.0.1.tgz: package/es/index.js <==
import { subspace, applyToRoot } from 'redux-subspace';
import { map, filter, ignoreElements } from 'rxjs/operators';
import { StateObservable, createEpicMiddleware as createEpicMiddleware$1 } from 'redux-observable';

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(source, true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(source).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _toPrimitive(input, hint) {
  if (typeof input !== "object" || input === null) return input;
  var prim = input[Symbol.toPrimitive];

  if (prim !== undefined) {
    var res = prim.call(input, hint || "default");
    if (typeof res !== "object") return res;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }

  return (hint === "string" ? String : Number)(input);
}

function _toPropertyKey(arg) {
  var key = _toPrimitive(arg, "string");

  return typeof key === "symbol" ? key : String(key);
}

var SUBSPACE_STORE_KEY = '@@redux-subspace/store';

var identity = function identity(x) {
  return x;
};

var subspaced = function subspaced(mapState, namespace) {
  var subspaceDecorator = subspace(mapState, namespace);
  return function (epic) {
    return function (action$, state$, _ref) {
      if (_ref === void 0) {
        _ref = {};
      }

      var _ref2 = _ref,
          parentStore = _ref2[SUBSPACE_STORE_KEY],
          dependencies = _objectWithoutPropertiesLoose(_ref2, [SUBSPACE_STORE_KEY].map(_toPropertyKey));

      if (parentStore === undefined) {
        throw new Error('Subspace epic couldn\'t find the store. Make sure you\'ve used createEpicMiddleware from redux-subspace-observable');
      }

      var subspacedStore = subspaceDecorator(parentStore);
      Object.defineProperty(dependencies, SUBSPACE_STORE_KEY, {
        enumerable: false,
        configurable: false,
        writable: false,
        value: subspacedStore
      });
      var subspacedState$ = new StateObservable(state$.pipe(map(subspacedStore.getState)), subspacedStore.getState());
      var filteredAction$ = action$.pipe(map(function (action) {
        return subspacedStore.processAction(action, identity);
      }), filter(identity));
      return epic(filteredAction$, subspacedState$, dependencies).pipe(map(subspacedStore.dispatch), ignoreElements());
    };
  };
};

var createEpicMiddleware = function createEpicMiddleware(options) {
  if (options === void 0) {
    options = {};
  }

  if (options.dependencies != null && (Array.isArray(options.dependencies) || typeof options.dependencies !== 'object')) {
    throw new TypeError('dependencies must be an object');
  }

  var subspaceEpicMiddleware = function subspaceEpicMiddleware(store) {
    var _objectSpread2$1;

    var optionsWithStore = _objectSpread2({}, options, {
      dependencies: _objectSpread2({}, options.dependencies, (_objectSpread2$1 = {}, _objectSpread2$1[SUBSPACE_STORE_KEY] = store, _objectSpread2$1))
    });

    var epicMiddleware = createEpicMiddleware$1(optionsWithStore);

    subspaceEpicMiddleware.run = function (rootEpic) {
      return epicMiddleware.run(rootEpic);
    };

    return epicMiddleware(store);
  };

  return applyToRoot(subspaceEpicMiddleware);
};

export { createEpicMiddleware, subspaced };

==> redux-subspace-observable-6.2.1.tgz: package/es/index.js <==
import { subspace, applyToRoot } from 'redux-subspace';
import { map, filter, ignoreElements } from 'rxjs/operators';
import { StateObservable, createEpicMiddleware as createEpicMiddleware$1 } from 'redux-observable';

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _toPrimitive(input, hint) {
  if (typeof input !== "object" || input === null) return input;
  var prim = input[Symbol.toPrimitive];

  if (prim !== undefined) {
    var res = prim.call(input, hint || "default");
    if (typeof res !== "object") return res;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }

  return (hint === "string" ? String : Number)(input);
}

function _toPropertyKey(arg) {
  var key = _toPrimitive(arg, "string");

  return typeof key === "symbol" ? key : String(key);
}

var SUBSPACE_STORE_KEY = '@@redux-subspace/store';

var identity = function identity(x) {
  return x;
};

var subspaced = function subspaced(mapState, namespace) {
  var subspaceDecorator = subspace(mapState, namespace);
  return function (epic) {
    return function (action$, state$, _ref) {
      if (_ref === void 0) {
        _ref = {};
      }

      var _ref2 = _ref,
          parentStore = _ref2[SUBSPACE_STORE_KEY],
          dependencies = _objectWithoutPropertiesLoose(_ref2, [SUBSPACE_STORE_KEY].map(_toPropertyKey));

      if (parentStore === undefined) {
        throw new Error('Subspace epic couldn\'t find the store. Make sure you\'ve used createEpicMiddleware from redux-subspace-observable');
      }

      var subspacedStore = subspaceDecorator(parentStore);
      Object.defineProperty(dependencies, SUBSPACE_STORE_KEY, {
        enumerable: false,
        configurable: false,
        writable: false,
        value: subspacedStore
      });
      var subspacedState$ = new StateObservable(state$.pipe(map(subspacedStore.getState)), subspacedStore.getState());
      var filteredAction$ = action$.pipe(map(function (action) {
        return subspacedStore.processAction(action, identity);
      }), filter(identity));
      return epic(filteredAction$, subspacedState$, dependencies).pipe(map(subspacedStore.dispatch), ignoreElements());
    };
  };
};

var createEpicMiddleware = function createEpicMiddleware(options) {
  if (options === void 0) {
    options = {};
  }

  if (options.dependencies != null && (Array.isArray(options.dependencies) || typeof options.dependencies !== 'object')) {
    throw new TypeError('dependencies must be an object');
  }

  var subspaceEpicMiddleware = function subspaceEpicMiddleware(store) {
    var _objectSpread2$1;

    var optionsWithStore = _objectSpread2(_objectSpread2({}, options), {}, {
      dependencies: _objectSpread2(_objectSpread2({}, options.dependencies), {}, (_objectSpread2$1 = {}, _objectSpread2$1[SUBSPACE_STORE_KEY] = store, _objectSpread2$1))
    });

    var epicMiddleware = createEpicMiddleware$1(optionsWithStore);

    subspaceEpicMiddleware.run = function (rootEpic) {
      return epicMiddleware.run(rootEpic);
    };

    return epicMiddleware(store);
  };

  return applyToRoot(subspaceEpicMiddleware);
};

export { createEpicMiddleware, subspaced };
